@@ -25,7 +25,7 @@ class ApiDocParams(ApiDocTags):
     def __init__(self):
         super().__init__()
         self.type = None
-        self.required = False
+        self.require = False
         self.example = None
         self.remark = None
 
@@ -146,7 +146,7 @@ class ApiDoc:
         apiDocParams.name = value
         apiDocParams.description = desc
         apiDocParams.type = type
-        apiDocParams.required = require
+        apiDocParams.require = require
         apiDocParams.example = example
         apiDocParams.remark = remark
         self.params.append(apiDocParams.__dict__)
@@ -210,7 +210,7 @@ class ApiDoc:
                     return ParamsErrorResponse(message = f"只允许{','.join([str(i) for i in method])}请求", code = 40003)
 
                 for i in params:
-                    if i.get('name') in list(form.keys()) or not i.get('required'):
+                    if i.get('name') in list(form.keys()) or i.get('require'):
                         if form.get(i.get('name')) == '' or form.get(i.get('name')) is None:
                             return ParamsErrorResponse(message = f"{i.get('name')}不能为空")
                     else:
